==> libexplain_0.11.D001.orig.tar.gz: libexplain-0.11.D001/explain/syscall/write.c <==
/*
 * libexplain - Explain errno values returned by libc functions
 * Copyright (C) 2008, 2009 Peter Miller
 * Written by Peter Miller <pmiller@opensource.org.au>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include <libexplain/ac/stdio.h>
#include <libexplain/ac/stdlib.h>

#include <libexplain/strtol_or_die.h>
#include <libexplain/write.h>
#include <libexplain/wrap_and_print.h>

#include <explain/syscall/write.h>


void
explain_syscall_write(int errnum, int argc, char **argv)
{
    int fildes = -1;
    void *data = 0;
    size_t data_size = 0;
    switch (argc)
    {
    case 0:
        fprintf(stderr, "write: no fildes given\n");
        exit(EXIT_FAILURE);

    case 3:
        data_size = explain_strtol_or_die(argv[2]);
        /* fall through... */

    case 2:
        data = (void *)explain_strtol_or_die(argv[1]);
        /* fall through... */

    case 1:
        fildes = explain_strtol_or_die(argv[0]);
        break;

    default:
        fprintf(stderr, "write: too many arguments given\n");
        exit(EXIT_FAILURE);
    }

    explain_wrap_and_print
    (
        stdout,
        explain_errno_write(errnum, fildes, data, data_size)
    );
}

==> libexplain_0.19.D001.orig.tar.gz: libexplain-0.19.D001/explain/syscall/write.c <==
/*
 * libexplain - Explain errno values returned by libc functions
 * Copyright (C) 2008, 2009 Peter Miller
 * Written by Peter Miller <pmiller@opensource.org.au>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include <libexplain/ac/stdio.h>
#include <libexplain/ac/stdlib.h>

#include <libexplain/strtol.h>
#include <libexplain/write.h>
#include <libexplain/wrap_and_print.h>

#include <explain/syscall/write.h>


void
explain_syscall_write(int errnum, int argc, char **argv)
{
    int fildes = -1;
    void *data = 0;
    size_t data_size = 0;
    switch (argc)
    {
    case 0:
        fprintf(stderr, "write: no fildes given\n");
        exit(EXIT_FAILURE);

    case 3:
        data_size = explain_strtol_or_die(argv[2], 0, 0);
        /* fall through... */

    case 2:
        data = (void *)explain_strtol_or_die(argv[1], 0, 0);
        /* fall through... */

    case 1:
        fildes = explain_strtol_or_die(argv[0], 0, 0);
        break;

    default:
        fprintf(stderr, "write: too many arguments given\n");
        exit(EXIT_FAILURE);
    }

    explain_wrap_and_print
    (
        stdout,
        explain_errno_write(errnum, fildes, data, data_size)
    );
}
